@@ -19,9 +19,10 @@ def getRandomColor():
 
 
 class NodeItem:
-    def __init__(self, nodeName, nodeId):
+    def __init__(self, nodeName, nodeId, label: str = None):
         self.nodeName = nodeName
         self.nodeId = nodeId
+        self.label = nodeName if label is None else label
 
 
 class GraphBase:
@@ -44,7 +45,7 @@ class GraphBase:
         # 记录当前图已经使用的 color
         self.currentUsedColor = {}
         # 记录常用的 hatch
-        self.hatches = ['', '/', 'o', '\\', 'O', '|', '-', '+', 'x', '.', '*',
+        self.hatches = ['', '/', 'o', 'x', '.', '\\', 'O', '|', '-', '+', 'x', '*',
                         '/o', '\\|', '|*', '-\\', '+o', 'x*', 'o-', 'O|', 'O.', '*-']
         self.currentUsedHatch = {}
         # 字体大小
@@ -154,11 +155,20 @@ class GraphBase:
             plt.ylim(*args, **kwargs)
         return self
 
+    def ticker_params(self, axis='both', **kwargs):
+        if self.ax is not None:
+            self.ax.tick_params(axis, **kwargs)
+        else:
+            plt.tick_params(axis, **kwargs)
+        return self
+
     def xticks(self, ticks=None, labels=None, **kwargs):
         if 'fontsize' not in kwargs:
             kwargs['fontsize'] = self.fontSize
         if self.ax is not None:
-            self.ax.set_xticks(ticks, labels, **kwargs)
+            self.ax.tick_params(labelsize=self.fontSize)
+            if ticks is not None:
+                self.ax.set_xticks(ticks, labels, **kwargs)
         else:
             plt.xticks(ticks, labels, **kwargs)
         return self
@@ -167,7 +177,9 @@ class GraphBase:
         if 'fontsize' not in kwargs:
             kwargs['fontsize'] = self.fontSize
         if self.ax is not None:
-            self.ax.set_yticks(ticks, labels, **kwargs)
+            self.ax.tick_params(labelsize=self.fontSize)
+            if ticks is not None:
+                self.ax.set_yticks(ticks, labels, **kwargs)
         else:
             plt.yticks(ticks, labels, **kwargs)
         return self
