@@ -119,55 +119,71 @@ class NodeAppDelay:
             return
         self.typeMap[item.Type.name].append(item)
 
-    def _sampling_interval(self, params: dict, start: int = 0, end: int = float("inf"), x_offset: float = 0) -> dict:
-        lastCount, res, x_v, y_v, tmp = 0, {}, 0, 0, []
-        delayType, samplingInterval, raw = \
-            params.get("delayType", DelayType.LastDelay), params.get("samplingInterval", 2), \
-            params.get("raw", -1)
-
+    def _pre_sample(self, intervals: List[tuple], params: dict):
+        delayType = params.get("delayType", DelayType.LastDelay)
+        result = {
+            'all': []
+        }
+        for interval in intervals:
+            result[f"{interval[0]}-{interval[1]}"] = []
         for i in range(len(self.typeMap[DelayType.FullDelay.name])):
             fullItem, lastItem = self.typeMap[DelayType.FullDelay.name][i], \
                                  self.typeMap[DelayType.LastDelay.name][i]
             full, last = fullItem.getValueByDelayTarget(DelayTarget.DelayMS), \
                          lastItem.getValueByDelayTarget(DelayTarget.DelayMS)
             # 过滤重传的包
-            if full - last > 10e-6 or last <= start or last > end:
+            if full - last > 10e-6:
                 continue
             item = self.typeMap[delayType.name][i]
+            result['all'].append(item)
+            for interval in intervals:
+                if last < interval[0]:
+                    break
+                if last < interval[1]:
+                    result[f"{interval[0]}-{interval[1]}"].append(item)
+                    break
+        return result
+
+    def _sampling_interval(self, items: List[DelayItem], params: dict, current_res: dict) -> dict:
+        lastCount, res, x_v, y_v, tmp = 0, {}, 0, 0, []
+        delayType, samplingInterval, raw = \
+            params.get("delayType", DelayType.LastDelay), params.get("samplingInterval", 2), \
+            params.get("raw", -1)
+
+        count = 0
+        for item in items:
+            last = item.getValueByDelayTarget(DelayTarget.DelayMS)
             if samplingInterval > 0:
                 # 采样
                 if raw == 0:
                     # 1. 采样区间内平均
                     if int(item.Time / samplingInterval) != lastCount:
                         lastCount = int(item.Time / samplingInterval)
-                        x_v = lastCount * samplingInterval + x_offset
+                        x_v = lastCount * samplingInterval
                         y_v = np.average(tmp)
                         tmp = []
-                        if y_v > start and y_v <= end:
-                            res[x_v] = y_v
+                        res[x_v] = y_v
                     else:
                         tmp.append(last)
                 elif raw > 0:
                     # 2. 按样本数间隔采样
-                    if i % samplingInterval == 0:
+                    if count % samplingInterval == 0:
                         x_v = item.Time
                         y_v = last
-                        if y_v > start and y_v <= end:
-                            res[x_v] = y_v
+                        res[x_v] = y_v
                 else:
                     # 3. 按时间间隔采样
                     if int(item.Time / samplingInterval) != lastCount:
                         lastCount = int(item.Time / samplingInterval)
-                        x_v = lastCount * samplingInterval + x_offset
+                        x_v = lastCount * samplingInterval
                         y_v = last
-                        if y_v > start and y_v <= end:
-                            res[x_v] = y_v
+                        res[x_v] = y_v
             else:
                 # 不采样，使用原始数据
                 x_v = item.Time
                 y_v = last
-                if y_v > start and y_v <= end:
-                    res[x_v] = y_v
+                res[x_v] = y_v
+            count += 1
         return res
 
     def _sampling(self, params: dict, get_x=True):
@@ -181,16 +197,43 @@ class NodeAppDelay:
             params.get("delayType", DelayType.LastDelay), params.get("samplingInterval", 2), \
             params.get("raw", -1), params.get("anomalyIntervalList", [])
 
+        # 处理分区
+        if len(anomalyIntervalList) == 0:
+            anomalyIntervalList = [(0, float("inf"))]
+        elif anomalyIntervalList[0][0] != 0:
+            anomalyIntervalList.insert(0, (0, anomalyIntervalList[0][0]))
+
+        # 得到预采样的结果
+        pre_sample_res = list(self._pre_sample(anomalyIntervalList[1:], params).values())
+        pre_sample_res
+
         # 1. 首先对全局进行采样
-        result = self._sampling_interval(params)
+        result = self._sampling_interval(pre_sample_res[0], params, {})
+        last_raw_count = len(pre_sample_res[0])
+        last_sample_count = len(result)
 
         # 2. 接着对每个异常区间采样
-        for idx, interval in enumerate(anomalyIntervalList):
-            tmp_result = self._sampling_interval(
-                params, interval[0], interval[1],
-                samplingInterval * idx + 1 / len(anomalyIntervalList)
-            )
-            result.update(tmp_result)
+        for i in range(1, len(pre_sample_res)):
+            cur_raw_samples = pre_sample_res[i]
+            params['raw'] = 1
+            params['samplingInterval'] = int(last_raw_count / last_sample_count / 2)
+            if params['samplingInterval'] > len(cur_raw_samples) / 10:
+                params['samplingInterval'] = int(len(cur_raw_samples) / 10)
+            if len(anomalyIntervalList[i]) == 3:
+                params['samplingInterval'] = anomalyIntervalList[i][2]
+            res = self._sampling_interval(cur_raw_samples, params, result)
+            if len(res) > 0:
+                last_raw_count = len(cur_raw_samples)
+                last_sample_count = len(res)
+            result.update(res)
+        params['raw'] = raw
+        params['samplingInterval'] = samplingInterval
+        # for idx, interval in enumerate(anomalyIntervalList):
+        #     tmp_result = self._sampling_interval(
+        #         params, interval[0], interval[1],
+        #         samplingInterval * idx + 1 / len(anomalyIntervalList)
+        #     )
+        #     result.update(tmp_result)
 
         # 3. 按时间排序
         keys = list(result.keys())
