@@ -3,6 +3,7 @@ from typing import Optional
 from .common import GraphBase, NodeItem, ExportItem, ExportBase
 import numpy as np
 import pandas as pd
+from collections.abc import Callable
 
 
 class ThroughputType(Enum):
@@ -383,6 +384,10 @@ class ThroughputGraph(GraphBase, ThroughputExtractBase, ExportBase):
             return self
         if "label" not in kwargs:
             kwargs["label"] = node.Node
+        if "nodeName" not in kwargs:
+            kwargs["nodeName"] = nodeName
+        if "nodeId" not in kwargs:
+            kwargs["nodeId"] = faceId
         x, y = node.getX(faceId, samplingInterval=self.samplingInterval), \
                node.getY(faceId, self.throughputType, self.throughputTarget, self.samplingInterval,
                          self.lpPacketHeaderSize)
@@ -392,7 +397,7 @@ class ThroughputGraph(GraphBase, ThroughputExtractBase, ExportBase):
                           linewidth=linewidth,
                           linestyle=linestyle,
                           marker=marker,
-                          markerfacecolor=markerfacecolor,
+                          markerfacecolor=color,
                           markersize=markersize,
                           **kwargs)
         return self
